"use strict";

require("core-js/modules/es6.object.assign");

var _assert = _interopRequireDefault(require("assert"));

var _index = _interopRequireWildcard(require("../index"));

var _helper = _interopRequireDefault(require("./helper"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ERROR_ID = 'form.errors.invalid';

function test(value, params) {
  return (0, _helper.default)((0, _index.format)(params)(value));
}

describe('Validator: format', function () {
  it("should be invalid when `value` doesn't match the with option", function () {
    _assert.default.strictEqual(ERROR_ID, test('', {
      with: /123/
    }));

    _assert.default.strictEqual(ERROR_ID, test(12, {
      with: /123/
    }));

    _assert.default.strictEqual(ERROR_ID, test('foo', {
      with: /bar/
    }));
  });
  it("should be invalid when `value` doesn't match the without option", function () {
    _assert.default.strictEqual(ERROR_ID, test('', {
      without: /.?/
    }));

    _assert.default.strictEqual(ERROR_ID, test(123, {
      without: /\d+/
    }));

    _assert.default.strictEqual(ERROR_ID, test('foo', {
      without: /\w+/
    }));
  });
  it('should be valid when `value` match the with option', function () {
    _assert.default.ok(!test('', {
      with: /.?/
    }));

    _assert.default.ok(!test(123, {
      with: /\d+/
    }));

    _assert.default.ok(!test('foo', {
      with: /\w+/
    }));
  });
  it('should be valid when `value` match the without option', function () {
    _assert.default.ok(!test('', {
      without: /123/
    }));

    _assert.default.ok(!test(12, {
      without: /123/
    }));

    _assert.default.ok(!test('foo', {
      without: /bar/
    }));
  });
  it('should use formatMessage', function () {
    var defaultValue = _index.default.formatMessage;

    _index.default.formatMessage = function (msg) {
      return Object.assign({}, msg, {
        id: msg.id + '2'
      });
    };

    _assert.default.strictEqual(ERROR_ID + '2', test(123, {
      without: /\d+/
    }));

    _index.default.formatMessage = defaultValue;
  });
});